@@ -7,11 +7,11 @@ class WhiteSpacePreprocessing():
     """
     Provides a very simple preprocessing script that filters infrequent tokens from text
     """
-    def __init__(self, documents, stopwords_language, vocabulary_size=2000):
+    def __init__(self, documents, stopwords_language="english", vocabulary_size=2000):
         """
 
-        :param documents:
-        :param stopwords_language:
+        :param documents: list of strings
+        :param stopwords_language: string of the language of the stopwords (see nltk stopwords)
         :param vocabulary_size: the number of most frequent words to include in the documents. Infrequent words will be discarded from the list of preprocessed documents
         """
         self.documents = documents
@@ -46,14 +46,3 @@ class WhiteSpacePreprocessing():
 
         return preprocessed_docs, unpreprocessed_docs, list(vocabulary)
 
-class SimplePreprocessing(WhiteSpacePreprocessing):
-    def __init__(self, documents, stopwords_language="english"):
-        super().__init__(documents, stopwords_language)
-        warnings.simplefilter('always', DeprecationWarning)
-
-        if self.__class__.__name__ == "CTM":
-
-            warnings.warn("SimplePrepocessing is deprecated and will be removed in version 2.0, "
-                          "use WhiteSpacePreprocessing", DeprecationWarning)
-
-
